allocate 98
open data c:\growth\bg2001nl.csv
data(format=cdf, org=obs, missing=-999)



set lnyl60 = log(yl60)
set lnyl95 = log(yl95)
set lnsk6095 = log(sk6095)
set lnngid6095 = log(glf6095+gavg6095+0.03)

set lnyllucas95 = lnyl95-(0.35/0.65)*lnsk6095+(0.35/0.65)*(lnngid6095)

nonlin zbar B sigma rho

frml lucaslevel lnyllucas95 = zbar
frml lucassk sk6095 = 0.35*(glf6095+gavg6095+0.03)/(rho+sigma*gavg6095+0.03)
frml lucasgi gavg6095=B*sh6095
frml lucassh sh6095=(1/sigma)*(1/B)*(B+glf6095-rho)

disp '***************************************'
disp 'SUR ESTIMATION OF LEVEL AND GROWTH RATE'
disp '***************************************'


smpl
equation one lnyllucas95
# constant
equation two gavg6095
# sh6095


sur(smpl=nonoil) 2
#one
#two

set ghat = %beta(2)*sh6095
set dum = %valid(ghat)*%valid(gavg6095)*nonoil
smpl(series=dum)
stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dum dhat dact x

sur(smpl=inter) 2
#one
#two

set ghat = %beta(2)*sh6095
set dum = %valid(ghat)*%valid(gavg6095)*inter
smpl(series=dum)
stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dum dhat dact x

sur(smpl=oecd) 2
#one
#two


set ghat = %beta(2)*sh6095
set dum = %valid(ghat)*%valid(gavg6095)*oecd
smpl(series=dum)
stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dum dhat dact x

sur(smpl=western) 2
#one
#two



set ghat = %beta(2)*sh6095
set dum = %valid(ghat)*%valid(gavg6095)*western
smpl(series=dum)
stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dum dhat dact x



disp '**************************'
disp 'ESTIMATION OF FULL SYSTEM'
disp '**************************'

compute B=0.2
compute zbar=8
compute rho=0.1
compute sigma=-0.1

smpl(series=nonoil)
nlsystem(iter=200) / lucaslevel lucassk lucasgi lucassh

set shhat = (1/%beta(3))*(1/%beta(2))*(%beta(2)+glf6095-%beta(4))
set dum = %valid(gavg6095)*%valid(glf6095)*nonoil
smpl(series=dum)

stat(noprint) shhat
compute shm = %mean
compute shstd = sqrt(%variance)
stat(noprint) sh6095
compute sham = %mean
compute shastd = sqrt(%variance)
set dhat = shhat-shm
set dact = sh6095-sham
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sh, shhat) ' (sum/(shstd*shastd*(%nobs-1)))
clear dhat dact x

set ghat = %beta(2)*shhat

stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dhat dact x



set skhat = 0.35*(glf6095+ghat+0.03)/(%beta(4)+%beta(3)*ghat+0.03)
stat(noprint) skhat
compute skm = %mean
compute skstd = sqrt(%variance)
stat(noprint) sk6095
compute skam = %mean
compute skastd = sqrt(%variance)
set dhat = skhat-skm
set dact = sk6095-skam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sk, skhat) ' (sum/(skstd*skastd*(%nobs-1)))
clear skhat shhat ghat dum dhat dact x


compute B=0.2
compute zbar=8
compute rho=0.1
compute sigma=-0.1

smpl(series=inter)
nlsystem(iter=200) / lucaslevel lucassk lucasgi lucassh

set shhat = (1/%beta(3))*(1/%beta(2))*(%beta(2)+glf6095-%beta(4))
set dum = %valid(gavg6095)*%valid(glf6095)*inter
smpl(series=dum)

stat(noprint) shhat
compute shm = %mean
compute shstd = sqrt(%variance)
stat(noprint) sh6095
compute sham = %mean
compute shastd = sqrt(%variance)
set dhat = shhat-shm
set dact = sh6095-sham
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sh, shhat) ' (sum/(shstd*shastd*(%nobs-1)))
clear dhat dact x

set ghat = %beta(2)*shhat

stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dhat dact x



set skhat = 0.35*(glf6095+ghat+0.03)/(%beta(4)+%beta(3)*ghat+0.03)
stat(noprint) skhat
compute skm = %mean
compute skstd = sqrt(%variance)
stat(noprint) sk6095
compute skam = %mean
compute skastd = sqrt(%variance)
set dhat = skhat-skm
set dact = sk6095-skam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sk, skhat) ' (sum/(skstd*skastd*(%nobs-1)))
clear skhat shhat ghat dum dhat dact x



compute B=0.2
compute zbar=8
compute rho=0.1
compute sigma=-0.1

smpl(series=oecd)
nlsystem(iter=200) / lucaslevel lucassk lucasgi lucassh

set shhat = (1/%beta(3))*(1/%beta(2))*(%beta(2)+glf6095-%beta(4))
set dum = %valid(gavg6095)*%valid(glf6095)*oecd
smpl(series=dum)

stat(noprint) shhat
compute shm = %mean
compute shstd = sqrt(%variance)
stat(noprint) sh6095
compute sham = %mean
compute shastd = sqrt(%variance)
set dhat = shhat-shm
set dact = sh6095-sham
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sh, shhat) ' (sum/(shstd*shastd*(%nobs-1)))
clear dhat dact x

set ghat = %beta(2)*shhat

stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dhat dact x



set skhat = 0.35*(glf6095+ghat+0.03)/(%beta(4)+%beta(3)*ghat+0.03)
stat(noprint) skhat
compute skm = %mean
compute skstd = sqrt(%variance)
stat(noprint) sk6095
compute skam = %mean
compute skastd = sqrt(%variance)
set dhat = skhat-skm
set dact = sk6095-skam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sk, skhat) ' (sum/(skstd*skastd*(%nobs-1)))
clear skhat shhat ghat dum dhat dact x




compute B=0.2
compute zbar=8
compute rho=0.1
compute sigma=-0.1

smpl(series=western)
nlsystem(iter=200) / lucaslevel lucassk lucasgi lucassh

set shhat = (1/%beta(3))*(1/%beta(2))*(%beta(2)+glf6095-%beta(4))
set dum = %valid(gavg6095)*%valid(glf6095)*western
smpl(series=dum)

stat(noprint) shhat
compute shm = %mean
compute shstd = sqrt(%variance)
stat(noprint) sh6095
compute sham = %mean
compute shastd = sqrt(%variance)
set dhat = shhat-shm
set dact = sh6095-sham
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sh, shhat) ' (sum/(shstd*shastd*(%nobs-1)))
clear dhat dact x

set ghat = %beta(2)*shhat

stat(noprint) ghat
compute gm = %mean
compute gstd = sqrt(%variance)
stat(noprint) gavg6095
compute gam = %mean
compute gastd = sqrt(%variance)
set dhat = ghat-gm
set dact = gavg6095-gam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(g, ghat) ' (sum/(gstd*gastd*(%nobs-1)))
clear dhat dact x


set skhat = 0.35*(glf6095+ghat+0.03)/(%beta(4)+%beta(3)*ghat+0.03)
stat(noprint) skhat
compute skm = %mean
compute skstd = sqrt(%variance)
stat(noprint) sk6095
compute skam = %mean
compute skastd = sqrt(%variance)
set dhat = skhat-skm
set dact = sk6095-skam
set x = dhat*dact
stat(noprint) x
compute sum = %mean*%nobs
disp 'Corr(sk, skhat) ' (sum/(skstd*skastd*(%nobs-1)))
clear skhat shhat ghat dum dhat dact x


